tracer

package module
v0.0.0-...-0a6b68f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 15, 2018 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Statsd

func Statsd(s string, startTime time.Time)

Statsd sends the stats to statsd instead of stdout.

func Trace

func Trace(s string) (string, time.Time)

Trace will print the provided string, and return the current time and the provided string.

func Un

func Un(s string, startTime time.Time)

Un is meant to be defered and wrapped around trace.

Types

type Tracer

type Tracer struct {
	Client g2s.Statter // The client implementation.
	Sample float32     // The sample rate.
}

Tracer is the struct for the reciever version of this client.

func New

func New(server, prefix string, sample float32) *Tracer

New is the method that creates the receiver version.

func (*Tracer) Statsd

func (t *Tracer) Statsd(s string, startTime time.Time)

Statsd sends the stats to statsd instead of stdout.

Jump to